import static helpers.Artist.DrawQuadTex;
import static helpers.Artist.QuickLoadTexture;
import java.io.IOException;
import java.util.ArrayList;
import org.lwjgl.input.Keyboard;
import org.lwjgl.opengl.Display;
import org.newdawn.slick.openal.Audio;
import org.newdawn.slick.openal.AudioLoader;
import org.newdawn.slick.opengl.Texture;
import org.newdawn.slick.util.ResourceLoader;



public class Player {

	public final String charTexture = "Character64";
	public final String charTextureLeft = "Character64_Left";
	public final String charTextureRight = "Character64_Right";
	public final String charTextureUp = "Character64_Up";
	public static final int PLAYER_DIM = 64; 
	public  boolean playerAlive = true;
	private int x, y ;
	private  int dx ,dy ;
	Texture playerTex;
	boolean hasCollided = false;
	private int collisionBuffer = 15; //Needed so the player can pass through 2 wall spaced by 1 grid
	Map map;
	BoundingBox hitbox = new BoundingBox(x +collisionBuffer,y +collisionBuffer ,x - collisionBuffer +PLAYER_DIM, y - collisionBuffer +PLAYER_DIM);
	ArrayList<Tile> CurrentMap;
	private Audio died;
	private Audio win;




	public Player(Map map, int startx, int starty) {

		CurrentMap = map.getTileArray();
		x = startx;
		y = starty;
		this.map = map;
		init();

	}
	
	public void init(){
		playerTex = QuickLoadTexture(charTexture);
		try {
			win = AudioLoader.getAudio("WAV", ResourceLoader.getResourceAsStream("res/WinSound.wav"));
			died = AudioLoader.getAudio("WAV", ResourceLoader.getResourceAsStream("res/Died.wav"));
		} catch (IOException e) {
			
			e.printStackTrace();
		}
	}

	public void render(){
		hitbox.setBoundingBox(x+collisionBuffer, y+collisionBuffer, x- collisionBuffer+PLAYER_DIM, y- collisionBuffer +PLAYER_DIM);
		DrawQuadTex(playerTex,x,y,64,64);
	}

	public void move(){
		if (Keyboard.isKeyDown(Keyboard.KEY_LEFT) && x > 0) {
			dx = -4;
	
			playerTex = QuickLoadTexture(charTextureLeft);
		}

		if (Keyboard.isKeyDown(Keyboard.KEY_RIGHT) && x < Display.getWidth()- PLAYER_DIM) {
			dx = 4;

			playerTex = QuickLoadTexture(charTextureRight);
		}

		if (Keyboard.isKeyDown(Keyboard.KEY_UP) && y > 0) {
			dy = -4;

			playerTex = QuickLoadTexture(charTexture);
		}

		if (Keyboard.isKeyDown(Keyboard.KEY_DOWN) && y < Display.getHeight() - PLAYER_DIM) {
			dy = 4;

			playerTex = QuickLoadTexture(charTexture);
		}
		update();
		
	}
	
	public boolean checkCollision(){

		hasCollided = false;
		for (int i = 0; i < CurrentMap.size(); i++) {
			//if you hit a wall you stop moving
			if (CurrentMap.get(i).isCollidable()) {
				if (hitbox.intersects(CurrentMap.get(i).getBoundingBox())) {
					hasCollided = true;
					System.out.println("Collision");
				}
			}
			//if you hit a lava box something needs to happen...I have to figure this out.
			if (CurrentMap.get(i).isCanKillPlayer()) {
				if (hitbox.intersects(CurrentMap.get(i).getBoundingBox())) {
					died.playAsSoundEffect(1.0f, 1.0f, false);
					setX(0);
					setY(0);
					ScoreBox.resetScore();
					System.out.println("dead");
				}
				
			}
			if (CurrentMap.get(i).isWin()) {
				if (hitbox.intersects(CurrentMap.get(i).getBoundingBox())) {
					setX(0);
					setY(0);
					win.playAsSoundEffect(1.0f, 1.0f, false);
					if(Game.levelState <= 3){
					Game.setLevelState(Game.levelState+=1);
					}
					else{
						Game.setLevelState(4);
					}
				}
				
			}
			
		}
		//System.out.println(hasCollided);
		return hasCollided;
	}

	public void update(){ 
		if (dx != 0 || dy != 0) {
			if (hasCollided) {
				dx = 0;
				dy = 0;
				hasCollided = false;
			}
			else{
				x+=dx;
				y+=dy;				
				dx = 0;
				dy = 0;
				
			}
		}

	}

	public boolean isPlayerAlive() {
		return playerAlive;
	}
	
	public void setPlayerAlive(boolean playerAlive) {

		this.playerAlive = playerAlive;
	}
	
	public int getX() {

		return x;
	}
	
	public void setX(int x) {

		this.x = x;
	}

	public int getY() {

		return y;
	}

	public void setY(int y) {

		this.y = y;
	}



}




